==> savane-1.0.3.1.tar.gz: savane/frontend/php/faq/export_html.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: export_html.php,v 1.7 2004/03/13 18:22:05 yeupou Exp $
#
#  Copyright 2002-2003 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

$group_id = $GLOBALS[sys_group_id];

$project=project_get_object($group_id);
$FAQ_DIR = $GLOBALS['sys_incdir'].'/faq';


function readFileIntoBuffer($filename)
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':readFileIntoBuffer($filename)';        
  
  @$fp = fopen($filename, "r");
  if ($fp)
    {
      $val = fread($fp, filesize($filename));
      fclose ($fp);
      return $val;
    }
  return false;
} 
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
        "http://www.w3.org/TR/REC-html40/loose.dtd">
<html>
<head>
    <title><?php print $GLOBALS[sys_name]." Frequently Asked Questions"; ?></title>
    <meta name="Generator" content="The Savannah FAQ system http://savannah.gnu.org">
</head>
<body>

<h1><?php print $GLOBALS[sys_name]." Frequently Asked Questions"; ?></h1>

<p><?php print $project->getDescription(); ?>

<p>Permission is granted to make and distribute verbatim copies of
 this manual provided the copyright notice and this permission notice
 are preserved on all copies.<br>

 Permission is granted to copy and distribute modified versions of this
 manual under the conditions for verbatim copying, provided that the entire
 resulting derived work is distributed under the terms of a permission
 notice identical to this one.<br>

 Permission is granted to copy and distribute translations of this manual
 into another language, under the above conditions for modified versions,
 except that this permission notice may be stated in a translation approved
 by the Free Software Foundation.<br>
<p>
<?php
     $dir = opendir($FAQ_DIR);
     while ($file = readdir($dir)) {
      if ($file != "." && $file != ".." && $file != "index.php" && $file != "CVS") {     
        $question = ereg_replace(".txt", "", $file);	
        $question = ereg_replace("_", " ", $question);
        echo '&nbsp;<a href="#'.$question.'">'.$question.'?</a><br>'; }
     } 
    closedir($dir);
?>
<p>
<?php
     $dir = opendir($FAQ_DIR);
     while ($file = readdir($dir)) {
      if ($file != "." && $file != ".." && $file != "index.php" && $file != "CVS") {    
        $question = ereg_replace(".txt", "", $file);	
        $question = ereg_replace("_", " ", $question);
	echo '<h2><a name="'.$question.'">'.$question.'?</a></h2>';
	
	$content = readFileIntoBuffer($FAQ_DIR."/".$file);
	echo utils_make_links($content);
	}
     } 
     closedir($dir);
              
?>

</body>
</html>

==> savane-1.0.4.tar.gz: savane/frontend/php/faq/export_html.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: export_html.php,v 1.8 2004/09/22 08:11:50 yeupou Exp $
#
#  Copyright 2002-2003 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

$group_id = $GLOBALS[sys_group_id];

$project=project_get_object($group_id);
$FAQ_DIR = $GLOBALS['sys_incdir'].'/faq';


function readFileIntoBuffer($filename)
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':readFileIntoBuffer($filename)';        
  
  @$fp = fopen($filename, "r");
  if ($fp)
    {
      $val = fread($fp, filesize($filename));
      fclose ($fp);
      return $val;
    }
  return false;
} 
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
        "http://www.w3.org/TR/REC-html40/loose.dtd">
<html>
<head>
    <title><?php print $GLOBALS[sys_name]." Frequently Asked Questions"; ?></title>
    <meta name="Generator" content="The Savannah FAQ system http://savannah.gnu.org">
</head>
<body>

<h1><?php print $GLOBALS[sys_name]." Frequently Asked Questions"; ?></h1>

<p><?php print $project->getDescription(); ?>

<p>Permission is granted to make and distribute verbatim copies of
 this manual provided the copyright notice and this permission notice
 are preserved on all copies.<br />

 Permission is granted to copy and distribute modified versions of this
 manual under the conditions for verbatim copying, provided that the entire
 resulting derived work is distributed under the terms of a permission
 notice identical to this one.<br />

 Permission is granted to copy and distribute translations of this manual
 into another language, under the above conditions for modified versions,
 except that this permission notice may be stated in a translation approved
 by the Free Software Foundation.<br />
<p>
<?php
     $dir = opendir($FAQ_DIR);
     while ($file = readdir($dir)) {
      if ($file != "." && $file != ".." && $file != "index.php" && $file != "CVS") {     
        $question = ereg_replace(".txt", "", $file);	
        $question = ereg_replace("_", " ", $question);
        echo '&nbsp;<a href="#'.$question.'">'.$question.'?</a><br />'; }
     } 
    closedir($dir);
?>
<p>
<?php
     $dir = opendir($FAQ_DIR);
     while ($file = readdir($dir)) {
      if ($file != "." && $file != ".." && $file != "index.php" && $file != "CVS") {    
        $question = ereg_replace(".txt", "", $file);	
        $question = ereg_replace("_", " ", $question);
	echo '<h2><a name="'.$question.'">'.$question.'?</a></h2>';
	
	$content = readFileIntoBuffer($FAQ_DIR."/".$file);
	echo utils_make_links($content);
	}
     } 
     closedir($dir);
              
?>

</body>
</html>
